Module ids

Module ids 

Run and step identifiers used by the engine to correlate crate::StreamChunks and crate::ChatMiddleware hooks.

Structs

RunId
Unique identifier for a single run of the engine.
StepId
Unique identifier for one provider turn (one model call) within a run.